from setuptools import setup, find_packages

setup(
    name='py-cone',
    packages=find_packages(),
    version='1.0.9',
    # install_requires=[
    # ],
    # extras_require={
    # },
    license='MIT',
    url='https://github.com/cone387/cone-python',
    python_requires='>=3.7, <4',
)
